@@ -1,11 +1,11 @@
+/* Copyright (C) 2011 Ben Bullock <bkb@cpan.org>. */
+
 #include "EXTERN.h"
 #include "perl.h"
 #include "XSUB.h"
 
 #include "ppport.h"
 
-#include "json_parse_lexer.h"
-#include "json_parse_grammar.tab.h"
 #include "json_parse.h"
 #include "json_argo.h"
 
@@ -19,6 +19,8 @@ typedef struct json_argo
 }
 json_argo_t;
 
+/* Debugging messages. */
+
 #define MESSAGE(format, args...) {                      \
         if (data->verbose) {                            \
             printf ("%s:%d: ", __FILE__, __LINE__);     \
